@@ -89,12 +89,13 @@ def pytest_generate_tests(metafunc):
     :param metafunc:
     :return:
     """
+    # keyword = metafunc.config.getoption("keyword")
+    # markexpr = metafunc.config.getoption("markexpr")
     # 获取当前待执行用例的文件名
     module_name = metafunc.module.__name__.split('.')[-1]
     func_file_path = metafunc.module.__file__
     # 获取当前待执行用例的函数名
     func_name = metafunc.function.__name__
-
     # 获取测试用例所属app
     belong_app = Path(func_file_path).relative_to(CASES_DIR).parts[0]
     # 获取当前用例对应的测试数据路径
@@ -188,7 +189,8 @@ def pytest_generate_tests(metafunc):
                 # 剔除标记disable的字段
                 deep_copied_case_data = disable_field(scenario.get("data"), deep_copied_case_data)
                 deep_copied_case_data["_scenario"] = item.get("scenario")
-                deep_copied_case_data["_ignore_failed"] = case_common.get("ignore_failed", False)
+                gloabl_ignore_failed = json.loads(metafunc.config.getini("ignore_error_and_continue"))
+                deep_copied_case_data["_ignore_failed"] = case_common.get("ignore_failed", gloabl_ignore_failed)
                 case_data_list.append(deep_copied_case_data)
                 ids.append(f'{case_data.get("title")} - {scenario.get("describe", "")}#{index + 1}')
             except KeyError as e:
@@ -199,7 +201,8 @@ def pytest_generate_tests(metafunc):
     else:
         if not case_common.get("ignore"):
             case_data["_scenario"] = {"data": {}}
-            case_data["_ignore_failed"] = case_common.get("ignore_failed", False)
+            gloabl_ignore_failed = json.loads(metafunc.config.getini("ignore_error_and_continue"))
+            case_data["_ignore_failed"] = case_common.get("ignore_failed", gloabl_ignore_failed)
             case_data_list = [case_data]
         # 进行参数化生成用例
         metafunc.parametrize("data", case_data_list, ids=[f'{case_data.get("title")}#1'], scope="function")
@@ -420,32 +423,25 @@ def pytest_runtest_call(item):
     :return:
     """
     origin_data = item.funcargs.get("data")
-    func_name = item.originalname
     ignore_failed = origin_data.get("_ignore_failed")
-    ignore_error_and_continue = item.config.getini("ignore_error_and_continue")
-    if not (ignore_failed is True or ignore_error_and_continue == "true"):
+    if not ignore_failed:
         # setup方法执行失败，则主动标记用例执行失败，不会执行用例
         if item.funcargs.get("setup_success") is False:
-            pytest.skip("test_before_scenario execute error")
+            pytest.skip(f"{item.nodeid} test_before_scenario execute error")
         # 判断上一个用例是否执行失败，如果上一个用例执行失败，则主动标记用例执行失败，不会执行用例（解决场景性用例，有一个失败则后续用例判为失败）
         index = item.session.items.index(item)
-        current_cls_name = item.parent.name
-        # 向前遍历，找到属于同一个类的用例
-        pattern = r"#(\d+)]"
-        current_turn = re.search(pattern, item.name)
-        if current_turn:
-            for prev_item in reversed(item.session.items[:index]):  # 只遍历当前 item 之前的
-                if prev_item.parent.name == current_cls_name and re.search(pattern, prev_item.name).group(
-                        1) == current_turn.group(1):  # 确保是同一个类
-                    status = getattr(prev_item, "status", None)  # 访问 status 属性
-                    skip_reason = getattr(prev_item, "skip_reason", None)  # 访问 skip_reason 属性
-                    if status == "skipped" and skip_reason.strip() in [
-                        "the previous method execution skipped",
-                        "the previous method execution failed",
-                        "test_before_scenario execute error"]:
-                        pytest.skip("the previous method execution skipped")
-                    elif status == "failed":
-                        pytest.skip("the previous method execution failed")
+        current_cls_name = item.nodeid.rsplit("::", 1)[0]  # 向前遍历，找到属于同一个类的用例
+        for prev_item in reversed(item.session.items[:index]):  # 只遍历当前 item 之前的
+            if current_cls_name == prev_item.nodeid.rsplit("::", 1)[0]:  # 确保是同一个类
+                status = getattr(prev_item, "status", None)  # 访问 status 属性
+                skip_reason = getattr(prev_item, "skip_reason", None)  # 访问 skip_reason 属性
+                if status == "skipped" and skip_reason.strip() in [
+                    "the previous method execution skipped",
+                    "the previous method execution failed",
+                    "test_before_scenario execute error"]:
+                    pytest.skip("the previous method execution skipped")
+                elif status == "failed":
+                    pytest.skip("the previous method execution failed")
 
     # 获取原始测试数据
     origin_data = item.funcargs.get("data")
@@ -486,7 +482,7 @@ def pytest_runtest_call(item):
 
 
 def pytest_runtest_teardown(item):
-    if item.funcargs.get("last") and getattr(item, "status", None) not in ["skipped", "failed"]:
+    if item.funcargs.get("last"):
         test_object = item.instance
         test_after_scenario = getattr(test_object, "test_teardown", None)
         if test_after_scenario:
