@@ -9,8 +9,8 @@ from box import Box
 from framework.exit_code import ExitCode
 from framework.utils.log_util import logger
 from framework.global_attribute import CONTEXT
-from framework.utils.common import SingletonFaker
-from config.settings import FAKER_LANGUAGE, DATA_DIR
+from framework.settings import FAKER_LANGUAGE, DATA_DIR
+from framework.utils.common import SingletonFaker, remove_spaces
 
 module = importlib.import_module("framework.utils.common")
 
@@ -34,11 +34,23 @@ class RenderData(object):
         """
         with allure.step("渲染数据"):
             self.replace_attribute(self.scenario)
+            self.render_url()
             self.replace_attribute(self.request)
         self.data["request"] = self.request
         self.data["_is_multipart"] = self._is_multipart
         return self.data
 
+    def render_url(self):
+        url = remove_spaces(self.request.url)
+        pattern = re.compile(r"\$\{([\w.\[\]0-9]+(?:\(\w*(?:,\w*)*\))?)}")
+
+        def replacer(match):
+            item = match.group(1)  # 拿到占位符里的内容
+            value = self.get_attribute(item)
+            return str(value) if value is not None else match.group(0)  # 未取到就保留原样
+
+        self.request.url = pattern.sub(replacer, url)
+        
     def replace_attribute(self, data):
         pattern = re.compile(r"\$\{([\w.\[\]0-9]+(?:\(\w*(?:,\w*)*\))?)}")
         file_path_pattern = re.compile(
@@ -52,6 +64,7 @@ class RenderData(object):
                     self.replace_attribute(value)
                 # 如果是字符串类型并匹配正则表达式，则替换
                 elif isinstance(value, str):
+                    value = remove_spaces(value)
                     if pattern.search(value):
                         data[key] = self.get_attribute(value[2:-1])
                     elif file_path_pattern.search(value):
@@ -66,6 +79,7 @@ class RenderData(object):
                     self.replace_attribute(item)
                 # 如果是字符串类型并匹配正则表达式，则替换
                 elif isinstance(item, str):
+                    item = remove_spaces(item)
                     if pattern.search(item):
                         data[index] = self.get_attribute(item[2:-1])
                     elif file_path_pattern.search(item):
@@ -73,7 +87,7 @@ class RenderData(object):
                         self._is_multipart = True
 
     def get_attribute(self, keyword):
-        if not keyword.endswith(")"):
+        if not keyword.strip().endswith(")"):
             return self.get_attribute_variable(keyword)
         # 如果关键字是函数
         else:
@@ -96,7 +110,7 @@ class RenderData(object):
         :param expression:
         :return:
         """
-        if not expression.startswith(tuple(f"{app}." for app in self.context.all_app)):
+        if not expression.strip().startswith(tuple(f"{app}." for app in self.context.all_app)):
             belong_app = self.data.get('_belong_app')
             new_expression = f"{belong_app}.{expression}"
         else:
@@ -108,23 +122,9 @@ class RenderData(object):
             if self.get_nested_value(self.context, new_expression) is not None else
             self.get_nested_value(self.context, expression)
         )
-        # if value.endswith(")}"):
-        #     keyword = value[2:-1]
-        #     try:
-        #         pattern = re.compile(r'(?P<func_name>.+)\((?P<args>.*)\)')
-        #         match = re.match(pattern, keyword)
-        #         # 匹配方法名
-        #         func_name = match.group("func_name")
-        #         # 匹配方法位置参数
-        #         args = match.group("args")
-        #         if args:
-        #             # 将参数中字符串类型的数字转成数字类型
-        #             args = [eval(i) for i in args.replace(",", "").split(",")]
-        #             value = self.get_func_variable(keyword, func_name, *args)
-        #         else:
-        #             value = self.get_func_variable(keyword, func_name)
-        #     except Exception:
-        #         pass
+        if isinstance(value, str) and value.strip().startswith("${") and value.strip().endswith("}"):
+            value = self.get_nested_value(self.context, new_expression) or self.get_nested_value(self.context,
+                                                                                                 expression)
 
         with allure.step(f"{expression}: {value}"):
             logger.info(f"前置读取变量: {expression}: {value}")
